@@ -250,6 +250,15 @@ class WindowComPositionAttributeData(Structure):
     ]
 
 
+class MARGINS(Structure):
+    _fields_ = [
+        ("cxLeftWidth", ctypes.c_int),
+        ("cxRightWidth", ctypes.c_int),
+        ("cyTopHeight", ctypes.c_int),
+        ("cyBottomHeight", ctypes.c_int),
+    ]
+
+
 def Error(text):
     try:
         from colorama import Fore
@@ -276,6 +285,11 @@ class DevManage(object):
         self.DwmGetColorizationColor = self.DwmApi.DwmGetColorizationColor
         self.SetWindowCompositionAttribute = self.Win32.SetWindowCompositionAttribute
 
+        self.DWMNCRP_USEWINDOWSTYLE = 0
+        self.DWMNCRP_DISABLED = 1
+        self.DWMNCRP_ENABLED = 2
+        self.DWMNCRP_LAS = 3
+
         self.DWMWCP_DEFAULT = 0
         self.DWMWCP_DONOTROUND = 1
         self.DWMWCP_ROUND = 2
@@ -388,7 +402,13 @@ class DevManage(object):
     def dwm_get_colorization_color(self):
         return self.DwmGetColorizationColor()
 
-    def dwm_enable_blurbehind_window(self, flags=0x00000001, enable: bool = True, rgn_blur=1, transition_on_maximized: bool = True):
+    def dwm_set_ncrendering_policy(self, value=2):
+        Value = ctypes.c_int(value)
+        self.dwm_set_window_attribute(self.DWMWA_NCRENDERING_POLICY,
+                                      ctypes.byref(Value), ctypes.sizeof(Value))
+
+    def dwm_enable_blurbehind_window(self, flags=0x00000001, enable: bool = True, rgn_blur=1,
+                                     transition_on_maximized: bool = True):
         BlurBehid = DWM_BLURBEHIND()
         BlurBehid.dwFlags = flags
         BlurBehid.fEnable = enable
@@ -399,6 +419,10 @@ class DevManage(object):
     def dwm_is_composition_enabled(self):
         return self.DwmApi.DwmIsCompositionEnabled()
 
+    def dwm_extend_frame_into_client_area(self, margins=[-1, -1, -1, -1]):
+        Margins = MARGINS(margins[0], margins[1], margins[2], margins[3])
+        return self.DwmApi.DwmExtendFrameIntoClientArea(self._master, ctypes.byref(Margins))
+
     def use_mica(self, is_dark=False):
         """
         使用Windows11的云母特效。
@@ -1612,5 +1636,4 @@ class DevTooltip(DevToplevel):
 if __name__ == '__main__':
     Window = DevWindow()
     Manage = DevManage(Window)
-    Manage.dwm_set_window_attribute_use_dark_mode()
     Window.mainloop()
